[Xfce4-commits] [apps/mousepad] 01/01: Fix typos

noreply at xfce.org noreply at xfce.org
Sun Aug 25 19:29:22 CEST 2019


This is an automated email from the git hooks/post-receive script.

a   n   d   r   e       p   u   s   h   e   d       a       c   o   m   m   i   t       t   o       b   r   a   n   c   h       m   a   s   t   e   r   
   in repository apps/mousepad.

commit 30e09c1626ea71353591836d8a2d86193ed29a70
Author: Andre Miranda <andreldm at xfce.org>
Date:   Sun Aug 25 14:29:08 2019 -0300

    Fix typos
---
 mousepad/mousepad-replace-dialog.c | 6 +++---
 mousepad/mousepad-util.c           | 8 ++++----
 mousepad/mousepad-util.h           | 4 ++--
 mousepad/mousepad-window.c         | 4 ++--
 4 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/mousepad/mousepad-util.c b/mousepad/mousepad-util.c
index 4f0893a..afdc640 100644
--- a/mousepad/mousepad-util.c
+++ b/mousepad/mousepad-util.c
@@ -844,10 +844,10 @@ mousepad_util_highlight (GtkTextBuffer       *buffer,
   /* initialize cache iters */
   cache_start = cache_end = iter;
 
-  /* highlight all the occurences of the strings */
+  /* highlight all the occurrences of the strings */
   do
     {
-      /* search for the next occurence of the string */
+      /* search for the next occurrence of the string */
       found = mousepad_util_search_iter (&iter, string, flags, &match_start, &match_end, &end);
 
       if (G_LIKELY (found))
@@ -862,14 +862,14 @@ mousepad_util_highlight (GtkTextBuffer       *buffer,
             {
               if (cached)
                 {
-                  /* highlight the cached occurences */
+                  /* highlight the cached occurrences */
                   gtk_text_buffer_apply_tag (buffer, tag, &cache_start, &cache_end);
 
                   /* cache is flushed */
                   cached = FALSE;
                 }
 
-              /* highlight the matched occurence */
+              /* highlight the matched occurrence */
               gtk_text_buffer_apply_tag (buffer, tag, &match_start, &match_end);
 
               /* set the new cache start iter */
diff --git a/mousepad/mousepad-util.h b/mousepad/mousepad-util.h
index 3923858..679f6fb 100644
--- a/mousepad/mousepad-util.h
+++ b/mousepad/mousepad-util.h
@@ -49,8 +49,8 @@ typedef enum
 
   /* actions */
   MOUSEPAD_SEARCH_FLAGS_ACTION_NONE       = 1 << 13, /* no visible actions */
-  MOUSEPAD_SEARCH_FLAGS_ACTION_HIGHTLIGHT = 1 << 14, /* highlight all the occurences */
-  MOUSEPAD_SEARCH_FLAGS_ACTION_CLEANUP    = 1 << 15, /* cleanup the highlighted occurences */
+  MOUSEPAD_SEARCH_FLAGS_ACTION_HIGHTLIGHT = 1 << 14, /* highlight all the occurrences */
+  MOUSEPAD_SEARCH_FLAGS_ACTION_CLEANUP    = 1 << 15, /* cleanup the highlighted occurrences */
   MOUSEPAD_SEARCH_FLAGS_ACTION_SELECT     = 1 << 16, /* select the match */
   MOUSEPAD_SEARCH_FLAGS_ACTION_REPLACE    = 1 << 17, /* replace the match */
 }
diff --git a/mousepad/mousepad-window.c b/mousepad/mousepad-window.c
index 65a2c5d..5b9016d 100644
--- a/mousepad/mousepad-window.c
+++ b/mousepad/mousepad-window.c
@@ -4728,7 +4728,7 @@ mousepad_window_action_find_next (GtkAction      *action,
   g_return_if_fail (MOUSEPAD_IS_WINDOW (window));
   g_return_if_fail (MOUSEPAD_IS_DOCUMENT (window->active));
 
-  /* find the next occurence */
+  /* find the next occurrence */
   if (G_LIKELY (window->search_bar != NULL))
     mousepad_search_bar_find_next (MOUSEPAD_SEARCH_BAR (window->search_bar));
 }
@@ -4742,7 +4742,7 @@ mousepad_window_action_find_previous (GtkAction      *action,
   g_return_if_fail (MOUSEPAD_IS_WINDOW (window));
   g_return_if_fail (MOUSEPAD_IS_DOCUMENT (window->active));
 
-  /* find the previous occurence */
+  /* find the previous occurrence */
   if (G_LIKELY (window->search_bar != NULL))
     mousepad_search_bar_find_previous (MOUSEPAD_SEARCH_BAR (window->search_bar));
 }

diff --git a/mousepad/mousepad-replace-dialog.c b/mousepad/mousepad-replace-dialog.c
index 8b4f44c..ac1d08f 100644
--- a/mousepad/mousepad-replace-dialog.c
+++ b/mousepad/mousepad-replace-dialog.c
@@ -419,7 +419,7 @@ mousepad_replace_dialog_response (GtkWidget *widget,
   /* update counter */
   if (replace_all)
     {
-      message = g_strdup_printf (ngettext ("%d occurence", "%d occurences", matches), matches);
+      message = g_strdup_printf (ngettext ("%d occurrence", "%d occurrences", matches), matches);
       gtk_label_set_markup (GTK_LABEL (dialog->hits_label), message);
       g_free (message);
     }
@@ -458,7 +458,7 @@ mousepad_replace_dialog_changed (MousepadReplaceDialog *dialog)
       /* not text, means no error */
       mousepad_util_entry_error (dialog->search_entry, FALSE);
 
       /* reset occurences label */
       gtk_label_set_text (GTK_LABEL (dialog->hits_label), NULL);
 
       /* buttons are not sensitive */
@@ -477,7 +477,7 @@ mousepad_replace_dialog_settings_changed (MousepadReplaceDialog *dialog,
                                           gchar                 *key,
                                           GSettings             *settings)
 {
   /* reset occurences label */
   gtk_label_set_text (GTK_LABEL (dialog->hits_label), NULL);
 
   mousepad_replace_dialog_changed (dialog);
@@ -458,7 +458,7 @@ mousepad_replace_dialog_changed (MousepadReplaceDialog *dialog)
       mousepad_util_entry_error (dialog->search_entry, FALSE);
 
-      /* reset occurences label */
+      /* reset occurrences label */
       gtk_label_set_text (GTK_LABEL (dialog->hits_label), NULL);
 
@@ -477,7 +477,7 @@ mousepad_replace_dialog_settings_changed (MousepadReplaceDialog *dialog,
                                           GSettings             *settings)
 {
-  /* reset occurences label */
+  /* reset occurrences label */
   gtk_label_set_text (GTK_LABEL (dialog->hits_label), NULL);
 
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list